@@ -17,7 +17,7 @@ import pandas as pd
 import ast
 
 
-def check_object(state, index, missing_msg=None, expand_msg=None, typestr="variable"):
+def check_object(state, index, missing_msg=None, expand_msg=None, typestr="переменную"):
     """Check object existence (and equality)
 
     Check whether an object is defined in the student's process, and zoom in on its value in both
@@ -235,7 +235,7 @@ def is_instance(state, inst, not_instance_msg=None):
     stu_name = state.student_parts.get("name")
 
     if not_instance_msg is None:
-        not_instance_msg = "Is it a {{inst.__name__}}?"
+        not_instance_msg = "Это {{inst.__name__}}?"
 
     if not isInstanceInProcess(sol_name, inst, state.solution_process):
         raise InstructorError.from_message(
